@@ -15,7 +15,8 @@
 using namespace Attica;
 
 DeleteJob::DeleteJob(PlatformDependent *internals, const QNetworkRequest &request)
-    : BaseJob(internals), m_request(request)
+    : BaseJob(internals)
+    , m_request(request)
 {
 }
 
@@ -29,3 +30,4 @@ QNetworkReply *DeleteJob::executeRequest()
     return platformDependentV2->deleteResource(m_request);
 }
 
+#include "moc_deletejob.cpp"
